# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## 1.1.0 (2020-02-21)
- Because of a breaking change in `cmd2`, we now require `cmd2>=0.10.0`

## 1.0.2 (2019-12-07)

### Added
- Add support for Python 3.8

### Fixed
- Because of a breaking change in `cmd2`, we now require `cmd2>=0.9.12`

### Removed
- Drop support for Python 3.4, which was end-of-life on 2019-03-18


## 1.0.1 (2018-07-22)

### Fixed
- Metadata for packaging


## 1.0.0 (2018-07-22)

### Added
- Created cmd2_abbrev plugin with example showing usage

